/*
 * msp432.h
 *
 */

#ifndef MSP432_H_
#define MSP432_H_

/* Include header files that are used in msp432.c */
    #include "uartstdio.h"
    #include <ti/devices/msp432e4/driverlib/driverlib.h>
    #include <ti/devices/msp432e4/driverlib/inc/hw_sysctl.h>
    #include <ti/drivers/i2c/I2CMSP432E4.h>

/* Function Prototypes */
    int init_CLK();
    int init_GPIO();
    int init_term_UART(uint32_t);
    int init_temp_I2C(uint32_t);
    void int_enable();
    void int_disable();

    void ConfigureuDMATX();

/* Function Variables */
    I2C_Handle            tempI2C;

#endif /* MSP432_H_ */
